structure T = Tokens;     

(* Types *)
type pos = int;
type svalue = Tokens.svalue;
type ('a,'b) token = ('a,'b) Tokens.token;
type lexresult= (svalue,pos) token;

type lexarg = string;
type arg = lexarg;

(* Error handling info for yacc *)
val lin = ref 1;
val col = ref 0 ;
val eolpos = ref 0 ;

(* End of file management *)
val eof = fn fileName => T.EOF (!lin,!col) ;

val atoi = fn (a,r) => ord(a)-ord(#"0")+10*r;
fun toInt l = if ((hd l)= #"~") then (~(toInt (tl l))) else (foldl atoi 0 l);

open Exp;
%%
%full
%header (functor BuildAstLexFun(structure Tokens: BuildAst_TOKENS));
%arg (fileName:string);
integer = [1-9][0-9]* | 0 | [~][1-9][0-9]*;
spaces = [\ \t \n];
alpha = [a-zA-Z];
alphanum = [a-zA-Z0-9_\'];
ws = [\t ];
%%
{ws}+		=> (continue ());
"\n"*		=> (T.NEW(!lin,!col));
"div"		=> (T.DIV(!lin,!col));
"mod"		=> (T.MOD(!lin,!col));
"*"		=> (T.MULT(!lin,!col));
"+"		=> (T.PLUS(!lin,!col));
"-"		=> (T.MINUS(!lin,!col));
"("		=> (T.LPAREN(!lin,!col));
")"		=> (T.RPAREN(!lin,!col));
{alpha}{alphanum}* => (T.IDENTIFIER(yytext,!lin,!col));
{integer}	=> (T.NUM((toInt (explode yytext)),!lin,!col));
.		=> (continue ());
