structure T = Tokens;     

(* Types *)
type pos = int;
type svalue = Tokens.svalue;
type ('a,'b) token = ('a,'b) Tokens.token;
type lexresult= (svalue,pos) token;

type lexarg = string;
type arg = lexarg;

(* Error handling info for yacc *)
val lin = ref 1;
val col = ref 0 ;
val eolpos = ref 0 ;

(* End of file management *)
val eof = fn fileName => T.EOF (!lin,!col) ;
fun len s = List.length(explode s);
val atoi = fn (a,r) => ord(a)-ord(#"0")+10*r;
val atof = fn (a,r) => real(ord(a)-ord(#"0"))+r/10.0;

fun realize l =  let
                        fun split [] l = (l,[])
                           |split (x::xs) l = if(x = #".") then (l,xs)
                                              else (split xs (x::l))
                        val (l1,l2) = split l []
                        val num = foldr atoi 0 l1
                        val frac = foldr atof 0.0 l2
                in
                real(num)+frac/10.0
                end;

fun toReal l = if((hd l)= #"~") then (~(realize (tl l))) else (realize l);
fun toInt l = if ((hd l)= #"~") then (~(toInt (tl l))) else (foldl atoi 0 l);
fun chop s = implode(rev(tl(rev(tl(explode s)))));

open DataTypes;
%%
%full
%header (functor BuildAstLexFun(structure Tokens: BuildAst_TOKENS));
%arg (fileName:string);
digit = [0-9];
integer = [1-9][0-9]* | 0 | [~][1-9][0-9]*;
dot = [.];
anat = [0-9]*[1-9];
spaces = [\ \t \n];
alpha = [a-zA-Z];
alphanum = [a-zA-Z0-9_\'];
ws = [\t ];
%%
{ws}+		=> ((col := !col + (len yytext));continue ());
"\n"		=> ((lin := !lin + 1);(col := 0);continue());
";"+		=> ((col := !col + (len yytext));T.NEW(!lin,!col));
"("		=> ((col := !col + 1);T.LPAREN(!lin,!col));
")"		=> ((col := !col + 1);T.RPAREN(!lin,!col));
"{"		=> ((col := !col + 1);T.LBRACE(!lin,!col));
"}"		=> ((col := !col + 1);T.RBRACE(!lin,!col));
"="		=> ((col := !col + 1);T.ASMT(!lin,!col));
","		=> ((col := !col + 1);T.COMMA(!lin,!col));
"program"	=> ((col := !col + 7);T.PROGRAM(!lin,!col));
"procedure"	=> ((col := !col + 9);T.PROC(!lin,!col));
"assign"	=> ((col := !col + 6);T.ASSIGN(!lin,!col));
"var"		=> ((col := !col + 3);T.VAR(!lin,!col));
"params"	=> ((col := !col + 6);T.PARAM(!lin,!col));
{alpha}{alphanum}* => ((col := !col + (len yytext));T.IDENTIFIER(yytext,!lin,!col));
{integer}{dot}{anat} | {integer}{dot}0 | "0.0" => ((col := !col + (len yytext));T.REAL((toReal (explode yytext)),!lin,!col));
{integer}	=> ((col := !col + (len yytext));T.NUM((toInt (explode yytext)),!lin,!col));
.		=> (continue ());
